==> blue2-xplore-booking-plugin-1.4.5-a22946.tar: assets/routes/YourDetails.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import { updateUser, hideCart } from '../redux/actions';

class YourDetails extends Component {
    constructor(props) {
        super(props);

        this.state = {
            height: window.innerHeight
        };
    }
    componentDidMount() {
        window.addEventListener('resize', this.resize);
    }

    resize = () => {
        this.props.hideCart(window.innerHeight < this.state.height);
    };

    render() {
        const { updateUser, name, surname, email, phoneNumber } = this.props;
        return (
            <>
                <h1>Your Details</h1>
                <div className="content">
                    <form className="your-details">
                        <input
                            type="text"
                            placeholder="First Name*"
                            name="firstName"
                            defaultValue={name}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Surname* "
                            name="surname"
                            defaultValue={surname}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Email*"
                            name="email"
                            defaultValue={email}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Phone Number*"
                            name="phoneNumber"
                            defaultValue={phoneNumber}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                    </form>
                </div>
            </>
        );
    }
}
// const YourDetails = ({ updateUser, hideCart, name, surname, email, phoneNumber }) => {
//     return (
//         <>
//             <h1>Your Details</h1>
//             <div className="content">
//                 <form
//                     className="your-details"
//                     onFocus={() => hideCart(true)}
//                     onBlur={() => hideCart(false)}>
//                     <input
//                         type="text"
//                         placeholder="First Name*"
//                         name="firstName"
//                         defaultValue={name}
//                         required
//                         onChange={e => updateUser(e.target)}
//                     />
//                     <input
//                         type="text"
//                         placeholder="Surname* "
//                         name="surname"
//                         defaultValue={surname}
//                         required
//                         onChange={e => updateUser(e.target)}
//                     />
//                     <input
//                         type="text"
//                         placeholder="Email*"
//                         name="email"
//                         defaultValue={email}
//                         required
//                         onChange={e => updateUser(e.target)}
//                     />
//                     <input
//                         type="text"
//                         placeholder="Phone Number*"
//                         name="phoneNumber"
//                         defaultValue={phoneNumber}
//                         required
//                         onChange={e => updateUser(e.target)}
//                     />
//                 </form>
//             </div>
//         </>
//     );
// };

const mapStateToProps = state => ({ ...state.user });

export default connect(
    mapStateToProps,
    { updateUser, hideCart }
)(YourDetails);

==> blue2-xplore-booking-plugin-1.4.6-844a7b.tar: assets/routes/YourDetails.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
import { updateUser, hideCart } from '../redux/actions';

class YourDetails extends Component {
    constructor(props) {
        super(props);

        this.state = {
            height: window.innerHeight,
            showButton: false
        };
    }
    componentDidMount() {
        window.addEventListener('resize', this.resize);
    }

    resize = () => {
        this.props.hideCart(window.innerHeight < this.state.height);
        this.setState({
            showButton: window.innerHeight < this.state.height
        });
    };

    render() {
        const { updateUser, name, surname, email, phoneNumber } = this.props;
        console.log(window.innerHeight, this.state.height);
        return (
            <>
                <h1>Your Details</h1>
                <div className="content">
                    <form className="your-details">
                        <input
                            type="text"
                            placeholder="First Name*"
                            name="firstName"
                            defaultValue={name}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Surname* "
                            name="surname"
                            defaultValue={surname}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Email*"
                            name="email"
                            defaultValue={email}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                        <input
                            type="text"
                            placeholder="Phone Number*"
                            name="phoneNumber"
                            defaultValue={phoneNumber}
                            required
                            onChange={e => updateUser(e.target)}
                        />
                    </form>
                    {this.state.showButton && (
                        <button
                            style={{ width: `100%` }}
                            className="primary continue-button mobile-only">
                            Continue
                        </button>
                    )}
                </div>
            </>
        );
    }
}

const mapStateToProps = state => ({ ...state.user });

export default connect(
    mapStateToProps,
    { updateUser, hideCart }
)(YourDetails);
